import * as React from "react";
import { style } from "typestyle";
import { ENVIRONMENT_PANEL_ID } from "../constants";
import { CondaEnvItem } from "./CondaEnvItem";
import { CondaEnvToolBar, ENVIRONMENT_TOOLBAR_HEIGHT } from "./CondaEnvToolBar";
export const ENVIRONMENT_PANEL_WIDTH = 250;
/**
 * React component for the environment list
 */
export const CondaEnvList = (props) => {
    let isDefault = false;
    const listItems = props.environments.map((env, idx) => {
        const selected = env.name === props.selected;
        if (selected) {
            // Forbid clone and removing the environment named "base" (base conda environment)
            // and the default one (i.e. the one containing JupyterLab)
            isDefault = env.is_default || env.name === "base";
        }
        return (React.createElement(CondaEnvItem, { name: env.name, key: env.name, selected: props.selected ? env.name === props.selected : false, onClick: props.onSelectedChange }));
    });
    return (React.createElement("div", { className: Style.Panel },
        React.createElement(CondaEnvToolBar, { isBase: isDefault, isPending: props.isPending, onCreate: props.onCreate, onClone: props.onClone, onImport: props.onImport, onExport: props.onExport, onRefresh: props.onRefresh, onRemove: props.onRemove }),
        React.createElement("div", { id: ENVIRONMENT_PANEL_ID, className: Style.ListEnvs(props.height - ENVIRONMENT_TOOLBAR_HEIGHT - 32) }, listItems)));
};
var Style;
(function (Style) {
    Style.Panel = style({
        flexGrow: 0,
        flexShrink: 0,
        display: "flex",
        flexDirection: "column",
        overflow: "hidden",
        width: ENVIRONMENT_PANEL_WIDTH
    });
    Style.ListEnvs = (height) => style({
        height: height,
        overflowY: "auto",
        display: "flex",
        flexDirection: "column"
    });
})(Style || (Style = {}));
//# sourceMappingURL=CondaEnvList.js.map