import * as React from "react";
import { Conda } from "../tokens";
import { PkgFilters } from "./CondaPkgToolBar";
/**
 * Package panel property
 */
export interface IPkgPanelProps {
    /**
     * Panel height
     */
    height: number;
    /**
     * Panel width
     */
    width: number;
    /**
     * Package manager for the selected environment
     */
    packageManager: Conda.IPackageManager;
}
/**
 * Package panel state
 */
export interface IPkgPanelState {
    /**
     * Is package list loading?
     */
    isLoading: boolean;
    /**
     * Is the package manager applying changes?
     */
    isApplyingChanges: boolean;
    /**
     * Does package list have description?
     */
    hasDescription: boolean;
    /**
     * Are there some packages updatable?
     */
    hasUpdate: boolean;
    /**
     * Packages list
     */
    packages: Conda.IPackage[];
    /**
     * Selected packages
     */
    selected: Conda.IPackage[];
    /**
     * Active filter
     */
    activeFilter: PkgFilters;
    /**
     * Current search term
     */
    searchTerm: string;
}
/** Top level React component for widget */
export declare class CondaPkgPanel extends React.Component<IPkgPanelProps, IPkgPanelState> {
    constructor(props: IPkgPanelProps);
    private _updatePackages;
    handleCategoryChanged(event: React.ChangeEvent<HTMLSelectElement>): void;
    handleClick(pkg: Conda.IPackage): void;
    handleVersionSelection(pkg: Conda.IPackage, version: string): void;
    handleSearch(event: any): void;
    handleUpdateAll(): Promise<void>;
    /**
     * Execute requested task in the following order
     * 1. Remove packages
     * 2. Apply updates
     * 3. Install new packages
     */
    handleApply(): Promise<void>;
    handleCancel(): void;
    handleRefreshPackages(): Promise<void>;
    componentDidUpdate(prevProps: IPkgPanelProps): void;
    render(): JSX.Element;
    private _model;
    private _currentEnvironment;
}
