import { ISettingRegistry } from "@jupyterlab/settingregistry";
import { ISignal } from "@lumino/signaling";
import { Conda, IEnvironmentManager } from "./tokens";
/**
 * Conda Environment Manager
 */
export declare class CondaEnvironments implements IEnvironmentManager {
    constructor(settings?: ISettingRegistry.ISettings);
    get environments(): Promise<Array<Conda.IEnvironment>>;
    get environmentChanged(): ISignal<IEnvironmentManager, Conda.IEnvironmentChange>;
    getPackageManager(name?: string): Conda.IPackageManager;
    /**
     * Test whether the manager is disposed.
     */
    get isDisposed(): boolean;
    /**
     * Get the list of packages to install for a given environment type.
     *
     * The returned package list is the input type split with " ".
     *
     * @param type Environment type
     * @returns List of packages to create the environment
     */
    getEnvironmentFromType(type: string): string[];
    /**
     * Get the list of user-defined environment types
     */
    get environmentTypes(): string[];
    /**
     * Load user settings
     *
     * @param settings User settings
     */
    private _updateSettings;
    /**
     * Dispose of the resources used by the manager.
     */
    dispose(): void;
    getChannels(name: string): Promise<Conda.IChannels>;
    clone(target: string, name: string): Promise<void>;
    create(name: string, type?: string): Promise<void>;
    export(name: string, fromHistory?: boolean | null): Promise<Response>;
    import(name: string, fileContent: string, fileName?: string): Promise<void>;
    refresh(): Promise<Array<Conda.IEnvironment>>;
    remove(name: string): Promise<void>;
    update(name: string, fileContent: string, fileName?: string): Promise<void>;
    private _clean;
    private _isDisposed;
    private _environmentChanged;
    private _environments;
    private _environmentsTimer;
    private _environmentTypes;
    private _fromHistory;
    private _packageManager;
    private _whitelist;
}
export declare class CondaPackage implements Conda.IPackageManager {
    /**
     * Conda environment of interest
     */
    environment?: string;
    constructor(environment?: string);
    get packageChanged(): ISignal<Conda.IPackageManager, Conda.IPackageChange>;
    /**
     * Refresh the package list.
     *
     * @param includeAvailable Include available package list
     * @param environment Environment name
     *
     * @returns The package list
     */
    refresh(includeAvailable?: boolean, environment?: string): Promise<Array<Conda.IPackage>>;
    install(packages: Array<string>, environment?: string): Promise<void>;
    develop(path: string, environment?: string): Promise<void>;
    check_updates(environment?: string): Promise<Array<string>>;
    update(packages: Array<string>, environment?: string): Promise<void>;
    remove(packages: Array<string>, environment?: string): Promise<void>;
    refreshAvailablePackages(cancellable?: boolean): Promise<void>;
    /**
     * Does the available packages have description?
     *
     * @returns description presence
     */
    hasDescription(): boolean;
    /**
     * Get the available packages list.
     *
     * @param force Force refreshing the available package list
     * @param cancellable Can this asynchronous action be cancelled?
     */
    private _getAvailablePackages;
    /**
     * Cancel optional tasks
     */
    private _cancelTasks;
    private _packageChanged;
    private _cancellableStack;
    private static _availablePackages;
    private static _hasDescription;
}
